@@ -6,7 +6,7 @@ use re 'eval';
 use Filter::Util::Call;
 use PPR;
 
-our $VERSION = '0.000002'; # v0.0.2
+our $VERSION = '0.000003'; # v0.0.3
 
 $VERSION = eval $VERSION;
 
@@ -37,36 +37,45 @@ sub import {
     return 0 if $done++;
     1 while filter_read();
     #warn "CODE >>>\n$_<<<";
-    local @Found;
-    unless (/(?&PerlDocument) $grammar/x) {
-      warn "Failed to parse file; expect complication errors, sorry.\n";
+    if (defined(my $mangled = mangle($_))) {
+      $_ = $mangled;
     }
-    my $offset = 0;
-    foreach my $case (@Found) {
-      my ($start, $len) = @$case;
-      $start += $offset;
-      my $stmt = substr($_, $start, $len);
-      die "Whit?"
-        unless my @match = $stmt =~ m{
-          \A
-          method ((?&PerlOWS))
-          ((?&PerlIdentifier)) ((?&PerlOWS))
-          (?: ((?&kw_balanced_parens)) ((?&PerlOWS)) )?+
-          ((?&PerlBlock)) ((?&PerlOWS))
-          $grammar
-        }x;
-      my ($ws0, $name, $ws1, $sig, $ws2, $block, $ws3) = @match;
-      my $sigcode = $sig ? " my $sig = \@_;" : '';
-      $block =~ s{^\{}{\{my \$self = shift;${sigcode}};
-      my $replace = "sub${ws0}${name}${ws1}${block}${ws3}";
-      substr($_, $start, $len) = $replace;
-      $offset += length($replace) - $len;
-    }
-    #warn "FINAL >>>\n$_<<<";
     return 1;
   });
 }
 
+sub mangle {
+  my ($code) = @_;
+  local @Found;
+  unless ($code =~ /\A (?&PerlDocument) \Z $grammar/x) {
+    warn "Failed to parse file; expect complication errors, sorry.\n";
+    return undef;
+  }
+  my $offset = 0;
+  foreach my $case (@Found) {
+    my ($start, $len) = @$case;
+    $start += $offset;
+    my $stmt = substr($code, $start, $len);
+    die "Whit?"
+      unless my @match = $stmt =~ m{
+        \A
+        method ((?&PerlOWS))
+        ((?&PerlIdentifier)) ((?&PerlOWS))
+        (?: ((?&kw_balanced_parens)) ((?&PerlOWS)) )?+
+        ((?&PerlBlock)) ((?&PerlOWS))
+        $grammar
+      }x;
+    my ($ws0, $name, $ws1, $sig, $ws2, $block, $ws3) = @match;
+    my $sigcode = $sig ? " my $sig = \@_;" : '';
+    $block =~ s{^\{}{\{my \$self = shift;${sigcode}};
+    my $replace = "sub${ws0}${name}${ws1}${block}${ws3}";
+    substr($code, $start, $len) = $replace;
+    $offset += length($replace) - $len;
+  }
+  #warn "FINAL >>>\n$_<<<";
+  return $code;
+}
+
 1;
 
 =head1 NAME
@@ -141,7 +150,15 @@ line to this module for fatpacking/shipping/etc. - I may yet come up with
 a better solution to this and/or beg Damian for help doing so, but at the
 time of writing I can offer no guarantees.
 
-Note that L<PPR> requires perl 5.10 and as such so does this module.
+Note that L<PPR> requires perl 5.10 and as such so does this module. However,
+if you need to support older perls, you can
+
+    use Method::Signatures::PP::Compile;
+
+which uses ingy's L<Module::Compile> to generate a .pmc file that should run
+fine on whatever version of perl the rest of your code requires. This will
+likely be rewritten to use a slightly less lunatic compilation mechanism in
+later releases.
 
 =head1 AUTHOR
 
